<?php

namespace Drupal\acquia_connector\Event;

use Drupal\acquia_connector\Subscription;
use Drupal\Component\EventDispatcher\Event;
use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Event to let individual products create configurations within Connector.
 */
class AcquiaProductSettingsEvent extends Event {

  use StringTranslationTrait;

  /**
   * The Connector Settings Form.
   *
   * @var array
   */
  protected $form;

  /**
   * The Connector Settings Form.
   *
   * @var \Drupal\Core\Form\FormStateInterface
   */
  protected $form_state;

  /**
   * Acquia Subscription.
   *
   * @var \Drupal\acquia_connector\Subscription
   */
  protected $subscription;

  /**
   * Pass in connector config by default to all events.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Acquia Connector settings.
   */
  public function __construct(array $form, FormStateInterface $form_state, Subscription $subscription) {
    $this->form = $form;
    $this->form_state = $form_state;
    $this->subscription = $subscription;
  }

  /**
   * Gets the form attached to the Event.
   *
   * @return array
   *   The settings form.
   */
  public function getForm() {
    return $this->form;
  }

  /**
   * Sets the 'product settings' key for the Connector form.
   *
   * @param string
   *   Product Name.
   * @param string
   *   Product Machine Name.
   * @param array
   *   Product Settings form.
   */
  public function setProductSettings($product, $product_machine_name, $product_setting_form) {
    $this->form['product_settings'][$product_machine_name] = [
      '#type' => 'fieldset',
      '#title' => $this->t("%product_name", ['%product_name' => $product]),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE
    ];
    $this->form['product_settings'][$product_machine_name]['settings'] = $product_setting_form;

  }

  /**
   * Retreives third party setting from Connector.
   *
   * @return mixed
   *   A reference to the value for that property, or NULL if the property does
   *   not exist.
   */
  public function getThirdPartySetting($module_name, $form_value) {
    return $this->form_state->get(['product_settings', $module_name, 'settings', $form_value]);
  }

  /**
   * Retrieve the Acquia Subscription
   *
   * @return \Drupal\acquia_connector\Subscription
   *   The Subscription.
   */
  public function getSubscription() {
    return $this->subscription;
  }

}
